#
# spec file for package fllog
#
# Copyright (c) 2023-2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fllog
Version:        1.2.8
Release:        1.7
Summary:        Ham Radio logging software
License:        GPL-2.0
Group:          Productivity/Hamradio/Other
URL:            http://www.w1hkj.com/
#Git-Clone:     https://git.code.sf.net/p/fldigi/fllog
Source:         http://sourceforge.net/projects/fldigi/files/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  fltk-devel
BuildRequires:  flxmlrpc-devel
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description
FLLOG is the logbook server that maintains a large set of QSO logbook fields
that will probably be sufficient for casual operating, contesting and some
certificate logging. All of the fields that are captured in the logbook are
maintained in an ADIF database that can be read by any logbook program that
can read the ADIF text format. The server can open any logbook adif file,
including those created by fldigi.

%prep
%setup -q

%build
export BUILD_DATE=`date -d@0`
export BUILD_USER=openSUSE
export BUILD_HOST=openSUSE
%configure
%make_build

%install
%make_install

%suse_update_desktop_file -i fllog

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/fllog
%{_datadir}/applications/fllog.desktop
%{_datadir}/pixmaps/fllog.xpm

%changelog
* Wed Jan 17 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 1.2.8
  * Main Window Icon: fix Fltk transpareny bug for fllog icon.
  * User Interface: Fixed several edge case behaviors with
    Combobox widgets
  * update to color font selection dialog
  * Add Submode support
    + Add Submode (ADIF entry "SUBMODE") field besides the mode input
    + Split the former mode input field horizontally into two by
    2:3 ratio
  * code fixes for fltk-1.4.0 compatability
  * remove recursive inclusing of config.h
  * deprecate "using namespace std" to avoid variable name
    conflicts with greedy g++ c11.
* Thu Jun 29 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Fix build for Tumbleweed and Factory
- New specfile based on fldigi specflie
* Sun Aug 15 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 1.2.7
  XmlRpc Client ID
  * add xmlrpc Client ID
  openSUSE Tumbleweed
  * correct Warnings & Errors exposed by gcc 11.1.1
  FD fields
  * change field field names to be compliant with ADIF spec
  mxe scripts
  * update mxe scripts
  export/import
  * change some existing field names
  * add fields to comply with fldigi logbook export/import
  * clean up various compiler warnings
  * correct terminate handler
  mkappbundle
  * modify 'version' to include VERSION_PATCH
* Thu Jun 20 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 1.2.6
  * update help file
  * create logs .1 ... .5 as aged backups
  * modify modes table for OLIVIA and HELL mode/sub-modes
  * restore saving / loading export field selections
  - right click on Default button; saves current selection
  - left click on Default button; selects default selection
  * remove separate status window; use debug event log window
    for status messages
  * add station call, operator call to xmlrpc add_record
  * updated interface specification
  * updated csv and text export
  * add mutex to prevent external request's overrunning prior
    actions.
  * add station QTH and LOCator to config items
  - initialize applicable "New" record fields
  * auto update log when fldigi sends eQSL
  * populate inpSearchCall with duplicate CALL
  * export FSKHELL-105 AS FMHELL
  * insure that same duplicates found independent of date-time
    sort ordering
  * xmlrpc interface to allow update of specified field. Not
    limited to eQSL and LoTW QSO dates
  * Restore previously viewed record when cancelling out of
    "new" record
  * Change to include both export_mode and export_submode
  * Changes imposed by recent changes in fldigi QSOdb structure
  * restore sort after merging database
* Thu Nov  8 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 1.2.5
- specfile cleanup
* Wed May 11 2016 dl8fcl@t-online.de
- update to version 1.2.3
* Sat Apr 30 2016 dl8fcl@t-online.de
- update to version 1.2.2
* Tue Apr 28 2015 dl8fcl@darc.de
- update to version 1.2.0
  requires libflxmlrpc
* Mon Jan 26 2015 dl8fcl@darc.de
- update to version 1.1.9, Maintenance release
* Tue Feb  4 2014 dl8fcl@darc.de
- update to version 1.1.8, Maintenance release
* Sun Jan  6 2013 dl8fcl@darc.de
- update to version 1.1.6, Maintenance release
* Mon Aug  6 2012 dl8fcl@darc.de
- update to version 1.1.5
* Mon Jun 25 2012 dl8fcl@darc.de
- update to version 1.1.3
* Thu Jan 26 2012 dl8fcl@darc.de
- update to version 1.1.1, build with fltk-1.1.10 and fltk-1.3.0
* Sun Nov 20 2011 dl8fcl@darc.de
- update to version 1.1.0
* Fri Jul  1 2011 dl8fcl@darc.de
- import into buildservice
